// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import ContactInfo, { type TContact } from '../ContactInfo'

type TContactItemList = { title: string, contact: TContact }[]

function ContactInfoList({
  items,
  icons,
  labels,
  showIcon,
  showLabel,
  theme,
}: {
  items: TContactItemList,
  icons: *,
  labels: *,
  showIcon?: boolean,
  showLabel?: boolean,
  theme: *,
}) {
  return (
    <div className={theme.root}>
      {items.map(({ title, contact }, idx) => (
        <div className={theme.itemWrapper} key={idx}>
          <div className={theme.title}>{title}</div>
          <ContactInfo
            contact={contact}
            icons={icons}
            labels={labels}
            showIcon={showIcon}
            showLabel={showLabel}
            theme={theme.item}
          />
        </div>
      ))}
    </div>
  )
}

export default themr('ContactInfoList', {
  root: 'pa2',
}, { composeTheme: 'softly' })(
  ContactInfoList,
)
