// @flow

import React from 'react'
import { withState, compose } from 'recompose'
import { themr } from 'react-css-themr'
import Lightbox from 'react-images'
import makeImageProps from 'components/Image/cloudinary'
import ImageList from 'components/ImageList'
import { type ImageProps } from 'components/Image'

function FeaturedImageGallery({
  items,
  largeCount = 2,
  smallCount = 3,
  isOpened,
  open,
  selected,
  select,
  theme,
}: {
  items: ImageProps[],
  largeCount?: number,
  smallCount?: number,
  isOpened: boolean,
  open: (isOpened?: boolean) => void,
  selected: number,
  select: (selected?: number) => void,
  theme: *,
}) {
  // const items = getImages(project)
  const galleries = items.map(({ image, src, alt, title }) => {
    if (!image) {
      return {
        src,
        // srcSet: srcset,
        alt,
        caption: title || alt,
      }
    }
    const cloudinaryImage = makeImageProps(image)
    return {
      src: cloudinaryImage.src,
      srcSet: cloudinaryImage.srcset,
      alt,
      caption: title || alt,
    }
  })
  const showMoreNumber = Math.max(items.length - 6, 0)
  return [
    <ImageList
      key="list"
      items={items}
      theme={theme}
      largeCount={largeCount}
      smallCount={smallCount}
      showMoreMessage={`+ ${showMoreNumber}`}
      onSelect={(value) => {
        open(true)
        select(value)
      }}
    />,
    <Lightbox
      key="lightbox"
      images={galleries}
      isOpen={isOpened}
      currentImage={selected}
      onClickPrev={() => select(selected - 1 < 0 ? selected : selected - 1)}
      onClickNext={() =>
        select(selected + 1 >= items.length ? 0 : selected + 1)
      }
      onClose={() => open(false)}
      showThumbnails
      onClickThumbnail={value => select(value)}
    />,
  ]
}

const defaultStyle = {
  root: 'flex flex-wrap',
  largeList: 'flex w-100 w-50-ns',
  largeWrapper: 'flex-auto pa1',
  largeImage: 'aspect-ratio--4x3 relative pointer',
  smallList: 'flex flex-wrap w-100 w-50-ns',
  smallWrapper: 'flex-auto w-50 pa1',
  smallImage: 'aspect-ratio--4x3 relative pointer',
  showMoreOverlay:
    'bg-black-30 hover-bg-black-40 flex items-center justify-center',
  showMore: 'white pf f5 fw4',
}


export default compose(
  themr('FeaturedImageGallery', defaultStyle, { composeTheme: 'softly' }),
  withState('isOpened', 'open', false),
  withState('selected', 'select', 0),
)(FeaturedImageGallery)
